@@ -128,6 +128,9 @@ INVALIDPARAMETER_DATE = 'InvalidParameter.Date'
 # 参数为空。
 INVALIDPARAMETER_EMPTYPARAMS = 'InvalidParameter.EmptyParams'
 
+# 不合法的EndPoint，请检查修改后重试。
+INVALIDPARAMETER_ENDPOINT = 'InvalidParameter.EndPoint'
+
 # 文件类型不合法。
 INVALIDPARAMETER_FILETYPE = 'InvalidParameter.FileType'
 
